# Dashboard arguments

Dashboard containers accept multiple arguments that can be used to customize them.

## API module arguments

| Argument name                | Default value                        | Description                                                                                                                                                                                                                                         |
|------------------------------|--------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| disable-csrf-protection      | false                                | Allows disabling CSRF protection.                                                                                                                                                                                                                   |
| act-as-proxy                 | false                                | Forces dashboard to work in full proxy mode, meaning that any internal in-cluster client calls are disabled.                                                                                                                                        |
| openapi-enabled              | false                                | Enables OpenAPI v2 endpoint user '/apidocs.json'. Used to autogenerate OpenAPI/GraphQL schema.                                                                                                                                                      |
| profiler                     | false                                | Enables pprof handler. By default it will be exposed on localhost:8070 under '/debug/pprof'.                                                                                                                                                        |
| prometheus-enabled           | false                                | Enables prometheus metrics handler. By default it will be exposed on localhost:8080 under '/metrics'.                                                                                                                                               |
| apiserver-skip-tls-verify    | false                                | Enable if connection with remote Kubernetes API should skip TLS verify.                                                                                                                                                                             |
| auto-generate-certificates   | false                                | When set to true, Dashboard will automatically generate certificates used to serve HTTPS.                                                                                                                                                           |
| cache-enabled                | true                                 | Whether the client cache should be enabled or not.                                                                                                                                                                                                  |
| cluster-context-enabled      | false                                | Whether multi-cluster cache context support should be enabled or not.                                                                                                                                                                               |
| cache-size                   | 1000                                 | Max number of cache entries to hold at once.                                                                                                                                                                                                        |
| cache-ttl                    | 10m                                  | Time to live of each cache entry.                                                                                                                                                                                                                   |
| cache-refresh-debounce       | 5s                                   | Minimal time between cache refreshes in background.                                                                                                                                                                                                 |
| insecure-port                | 8000                                 | The port to listen to for incoming HTTP requests.                                                                                                                                                                                                   |
| port                         | 8001                                 | The secure port to listen to for incoming HTTPS requests.                                                                                                                                                                                           |
| metric-client-check-period   | 30                                   | Time in seconds that defines how often configured metric client health check should be run.                                                                                                                                                         |
| insecure-bind-address        | 127.0.0.1                            | The IP address on which to serve the `--insecure-port` (set to 127.0.0.1 for loopback only).                                                                                                                                                        |
| bind-address                 | 0.0.0.0                              | The IP address on which to serve the `--port` (set to 0.0.0.0 for all interfaces).                                                                                                                                                                  |
| token-exchange-endpoint      | -                                    | Endpoint used when `--cluster-context-enabled=true` to exchange auth token for the unique context identifier.                                                                                                                                       |
| default-cert-dir             | /certs                               | Directory path containing `--tls-cert-file` and `--tls-key-file` files. Used also when auto-generating certificates flag is set. Relative to the container, not the host.                                                                           |
| tls-cert-file                | -                                    | File containing the default x509 Certificate for HTTPS.                                                                                                                                                                                             |
| tls-key-file                 | -                                    | File containing the default x509 private key matching --tls-cert-file.                                                                                                                                                                              |
| apiserver-host               | -                                    | The address of the Kubernetes Apiserver to connect to in the format of protocol://address:port, e.g., http://localhost:8080. If not specified, the assumption is that the binary runs inside a Kubernetes cluster and local discovery is attempted. |
| metrics-provider             | sidecar                              | Select provider type for metrics. 'none' will not check metrics.                                                                                                                                                                                    |
| sidecar-host                 | -                                    | The address of the Sidecar Apiserver to connect to in the format of protocol://address:port, e.g., http://localhost:8000. If not specified, the assumption is that the binary runs inside a Kubernetes cluster and service proxy will be used.      |
| kubeconfig                   | -                                    | Path to kubeconfig file with control plane location information.                                                                                                                                                                                    |
| namespace                    | kubernetes-dashboard                 | Namespace to use when accessing Dashboard specific resources, i.e. metrics scraper service.                                                                                                                                                         |
| metrics-scraper-service-name | kubernetes-dashboard-metrics-scraper | Name of the dashboard metrics scraper service.                                                                                                                                                                                                      |
| csrf-key                     | -                                    | Base64 encoded random 256 bytes key. Can be loaded from 'CSRF_KEY' environment variable.                                                                                                                                                            |
| v                            | 1                                    | Number for the log level verbosity (default 1)                                                                                                                                                                                                      | |

## Auth module arguments

| Argument name             | Default value | Description                                                                                                                                                                                                                                         |
|---------------------------|---------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| apiserver-skip-tls-verify | false         | Enable if connection with remote Kubernetes API should skip TLS verify.                                                                                                                                                                             |
| port                      | 8000          | The secure port to listen to for incoming HTTPS requests.                                                                                                                                                                                           |
| address                   | 0.0.0.0       | The IP address on which to serve the `--port` (set to 0.0.0.0 for all interfaces).                                                                                                                                                                  |
| kubeconfig                | -             | Path to `kubeconfig` file.                                                                                                                                                                                                                          |
| apiserver-host            | -             | The address of the Kubernetes Apiserver to connect to in the format of protocol://address:port, e.g., http://localhost:8080. If not specified, the assumption is that the binary runs inside a Kubernetes cluster and local discovery is attempted. |
| csrf-key                  | -             | Base64 encoded random 256 bytes key. Can be loaded from 'CSRF_KEY' environment variable.                                                                                                                                                            |
| v                         | 1             | Number for the log level verbosity (default 1)                                                                                                                                                                                                      |                                                                                                                                                                                                                                                                                                |# Metrics scraper module arguments

## Metrics scraper module arguments

| Argument name     | Default value   | Description                                                               |
|-------------------|-----------------|---------------------------------------------------------------------------|
| metric-resolution | 1m              | The resolution at which dashboard-metrics-scraper will poll metrics.      |
| metric-duration   | 15m             | The duration after which metrics are purged from the database.            |
| kubeconfig        | -               | Path to `kubeconfig` file.                                                |
| db-file           | /tmp/metrics.db | What file to use as a SQLite3 database.                                   |
| namespaces        | -               | Namespaces to use for all metric calls. When provided, skip node metrics. |
| v                 | 1               | Number for the log level verbosity (default 1)                            |                                                                                                                                                                                                                                                                                                |

## Web module arguments

| Argument name              | Default value                 | Description                                                                                                                                                               |
|----------------------------|-------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| auto-generate-certificates | false                         | When set to true, Dashboard will automatically generate certificates used to serve HTTPS.                                                                                 |
| insecure-port	             | 8000                          | The port to listen to for incoming HTTP requests.                                                                                                                         |
| port                       | 8001                          | The secure port to listen to for incoming HTTPS requests.                                                                                                                 |
| insecure-bind-address      | 127.0.0.1                     | The IP address on which to serve the `--insecure-port` (set to 127.0.0.1 for loopback only).                                                                              |
| bind-address               | 0.0.0.0                       | The IP address on which to serve the `--port` (set to 0.0.0.0 for all interfaces).                                                                                        |
| namespace                  | kube-system                   | Namespace to use when creating Dashboard specific resources, i.e. settings config map.                                                                                    |
| default-cert-dir           | /certs                        | Directory path containing `--tls-cert-file` and `--tls-key-file` files. Used also when auto-generating certificates flag is set. Relative to the container, not the host. |
| tls-cert-file              | -                             | File containing the default x509 Certificate for HTTPS.                                                                                                                   |
| tls-key-file               | -                             | File containing the default x509 private key matching --tls-cert-file.                                                                                                    |
| settings-config-map-name   | kubernetes-dashboard-settings | Name of a config map, that stores settings.                                                                                                                               |
| system-banner              | -                             | When non-empty displays message to Dashboard users. Accepts simple HTML tags.                                                                                             |
| system-banner-severity     | INFO                          | Severity of system banner. Should be one of `INFO\|WARNING\|ERROR`.                                                                                                       |
| locale-config              | ./locale_conf.json            | File containing the configuration of locales.                                                                                                                             |
| kubeconfig                 | -                             | Path to `kubeconfig` file.                                                                                                                                                |
| v                          | 1                             | Number for the log level verbosity (default 1)                                                                                                                            |                                                                                                                                                                                                                                                                                                |

----
_Copyright 2019 [The Kubernetes Dashboard Authors](https://github.com/kubernetes/dashboard/graphs/contributors)_
